@@ -4,6 +4,6 @@ Maps command aliases to their actual tool module names.
 """
 
 TOOL_ALIASES = {
-    'compare': 'colcompare',
-    'rowcount': 'dbstats',
+    "compare": "colcompare",
+    "rowcount": "dbstats",
 }
